AnimatedSlideArrow class

A widget that displays a continuously looping animated arrow, typically used to indicate a sliding or swipe action.

This widget can be used independently or integrated into buttons, forms, or custom UI to draw user attention to a sliding gesture.

Inheritance

Constructors

AnimatedSlideArrow({Key? key, Duration animationDuration = const Duration(seconds: 2), Duration animationDelay = const Duration(milliseconds: 200), Offset beginOffset = const Offset(-2, 0), Offset endOffset = const Offset(0, 0), Curve slideCurve = Curves.easeInOutQuart, double arrowHeight = 18, required ImageProvider<Object> arrowImage})
Creates an AnimatedSlideArrow widget.
const

Properties

animationDelay Duration
The delay between the end of one animation and the start of the next.
final
animationDuration Duration
The duration of one complete slide and fade animation cycle.
final
arrowHeight double
The height of the arrow image.
final
arrowImage ImageProvider<Object>
The image to use for the arrow.
final
beginOffset Offset
The starting position of the arrow in the slide animation.
final
endOffset Offset
The ending position of the arrow in the slide animation.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slideCurve Curve
The curve used for the slide animation.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AnimatedSlideArrow>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited