AnimatedSlideArrow constructor

const AnimatedSlideArrow({
  1. Key? key,
  2. Duration animationDuration = const Duration(seconds: 2),
  3. Duration animationDelay = const Duration(milliseconds: 200),
  4. Offset beginOffset = const Offset(-2, 0),
  5. Offset endOffset = const Offset(0, 0),
  6. Curve slideCurve = Curves.easeInOutQuart,
  7. double arrowHeight = 18,
  8. required ImageProvider<Object> arrowImage,
})

Creates an AnimatedSlideArrow widget.

The arrowImage parameter is required and specifies the image to use for the arrow. You can customize the duration, delay, direction, animation curve, and arrow size.

Implementation

const AnimatedSlideArrow({
  super.key,
  this.animationDuration = const Duration(seconds: 2),
  this.animationDelay = const Duration(milliseconds: 200),
  this.beginOffset = const Offset(-2, 0),
  this.endOffset = const Offset(0, 0),
  this.slideCurve = Curves.easeInOutQuart,
  this.arrowHeight = 18,
  required this.arrowImage,
});