arrowHeight property
The height of the arrow image.
The width will be determined automatically based on the image aspect ratio.
Implementation
final double arrowHeight;
The height of the arrow image.
The width will be determined automatically based on the image aspect ratio.
final double arrowHeight;