beginOffset property
The starting position of the arrow in the slide animation.
Defaults to Offset(-2, 0) to start the arrow off-screen to the left.
Implementation
final Offset beginOffset;
The starting position of the arrow in the slide animation.
Defaults to Offset(-2, 0) to start the arrow off-screen to the left.
final Offset beginOffset;